# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class DlnaProfilesDlnaProfile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'DlnaProfilesDeviceProfileType',
        'path': 'str',
        'user_id': 'str',
        'album_art_pn': 'str',
        'max_album_art_width': 'int',
        'max_album_art_height': 'int',
        'max_icon_width': 'int',
        'max_icon_height': 'int',
        'friendly_name': 'str',
        'manufacturer': 'str',
        'manufacturer_url': 'str',
        'model_name': 'str',
        'model_description': 'str',
        'model_number': 'str',
        'model_url': 'str',
        'serial_number': 'str',
        'enable_album_art_in_didl': 'bool',
        'enable_single_album_art_limit': 'bool',
        'enable_single_subtitle_limit': 'bool',
        'protocol_info': 'str',
        'timeline_offset_seconds': 'int',
        'requires_plain_video_items': 'bool',
        'requires_plain_folders': 'bool',
        'ignore_transcode_byte_range_requests': 'bool',
        'supports_samsung_bookmark': 'bool',
        'identification': 'DlnaProfilesDeviceIdentification',
        'protocol_info_detection': 'DlnaProfilesProtocolInfoDetection',
        'name': 'str',
        'id': 'str',
        'supported_media_types': 'str',
        'max_streaming_bitrate': 'int',
        'music_streaming_transcoding_bitrate': 'int',
        'max_static_music_bitrate': 'int',
        'direct_play_profiles': 'list[DirectPlayProfile]',
        'transcoding_profiles': 'list[TranscodingProfile]',
        'container_profiles': 'list[ContainerProfile]',
        'codec_profiles': 'list[CodecProfile]',
        'response_profiles': 'list[ResponseProfile]',
        'subtitle_profiles': 'list[SubtitleProfile]'
    }

    attribute_map = {
        'type': 'Type',
        'path': 'Path',
        'user_id': 'UserId',
        'album_art_pn': 'AlbumArtPn',
        'max_album_art_width': 'MaxAlbumArtWidth',
        'max_album_art_height': 'MaxAlbumArtHeight',
        'max_icon_width': 'MaxIconWidth',
        'max_icon_height': 'MaxIconHeight',
        'friendly_name': 'FriendlyName',
        'manufacturer': 'Manufacturer',
        'manufacturer_url': 'ManufacturerUrl',
        'model_name': 'ModelName',
        'model_description': 'ModelDescription',
        'model_number': 'ModelNumber',
        'model_url': 'ModelUrl',
        'serial_number': 'SerialNumber',
        'enable_album_art_in_didl': 'EnableAlbumArtInDidl',
        'enable_single_album_art_limit': 'EnableSingleAlbumArtLimit',
        'enable_single_subtitle_limit': 'EnableSingleSubtitleLimit',
        'protocol_info': 'ProtocolInfo',
        'timeline_offset_seconds': 'TimelineOffsetSeconds',
        'requires_plain_video_items': 'RequiresPlainVideoItems',
        'requires_plain_folders': 'RequiresPlainFolders',
        'ignore_transcode_byte_range_requests': 'IgnoreTranscodeByteRangeRequests',
        'supports_samsung_bookmark': 'SupportsSamsungBookmark',
        'identification': 'Identification',
        'protocol_info_detection': 'ProtocolInfoDetection',
        'name': 'Name',
        'id': 'Id',
        'supported_media_types': 'SupportedMediaTypes',
        'max_streaming_bitrate': 'MaxStreamingBitrate',
        'music_streaming_transcoding_bitrate': 'MusicStreamingTranscodingBitrate',
        'max_static_music_bitrate': 'MaxStaticMusicBitrate',
        'direct_play_profiles': 'DirectPlayProfiles',
        'transcoding_profiles': 'TranscodingProfiles',
        'container_profiles': 'ContainerProfiles',
        'codec_profiles': 'CodecProfiles',
        'response_profiles': 'ResponseProfiles',
        'subtitle_profiles': 'SubtitleProfiles'
    }

    def __init__(self, type=None, path=None, user_id=None, album_art_pn=None, max_album_art_width=None, max_album_art_height=None, max_icon_width=None, max_icon_height=None, friendly_name=None, manufacturer=None, manufacturer_url=None, model_name=None, model_description=None, model_number=None, model_url=None, serial_number=None, enable_album_art_in_didl=None, enable_single_album_art_limit=None, enable_single_subtitle_limit=None, protocol_info=None, timeline_offset_seconds=None, requires_plain_video_items=None, requires_plain_folders=None, ignore_transcode_byte_range_requests=None, supports_samsung_bookmark=None, identification=None, protocol_info_detection=None, name=None, id=None, supported_media_types=None, max_streaming_bitrate=None, music_streaming_transcoding_bitrate=None, max_static_music_bitrate=None, direct_play_profiles=None, transcoding_profiles=None, container_profiles=None, codec_profiles=None, response_profiles=None, subtitle_profiles=None):  # noqa: E501
        """DlnaProfilesDlnaProfile - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._path = None
        self._user_id = None
        self._album_art_pn = None
        self._max_album_art_width = None
        self._max_album_art_height = None
        self._max_icon_width = None
        self._max_icon_height = None
        self._friendly_name = None
        self._manufacturer = None
        self._manufacturer_url = None
        self._model_name = None
        self._model_description = None
        self._model_number = None
        self._model_url = None
        self._serial_number = None
        self._enable_album_art_in_didl = None
        self._enable_single_album_art_limit = None
        self._enable_single_subtitle_limit = None
        self._protocol_info = None
        self._timeline_offset_seconds = None
        self._requires_plain_video_items = None
        self._requires_plain_folders = None
        self._ignore_transcode_byte_range_requests = None
        self._supports_samsung_bookmark = None
        self._identification = None
        self._protocol_info_detection = None
        self._name = None
        self._id = None
        self._supported_media_types = None
        self._max_streaming_bitrate = None
        self._music_streaming_transcoding_bitrate = None
        self._max_static_music_bitrate = None
        self._direct_play_profiles = None
        self._transcoding_profiles = None
        self._container_profiles = None
        self._codec_profiles = None
        self._response_profiles = None
        self._subtitle_profiles = None
        self.discriminator = None
        if type is not None:
            self.type = type
        if path is not None:
            self.path = path
        if user_id is not None:
            self.user_id = user_id
        if album_art_pn is not None:
            self.album_art_pn = album_art_pn
        if max_album_art_width is not None:
            self.max_album_art_width = max_album_art_width
        if max_album_art_height is not None:
            self.max_album_art_height = max_album_art_height
        if max_icon_width is not None:
            self.max_icon_width = max_icon_width
        if max_icon_height is not None:
            self.max_icon_height = max_icon_height
        if friendly_name is not None:
            self.friendly_name = friendly_name
        if manufacturer is not None:
            self.manufacturer = manufacturer
        if manufacturer_url is not None:
            self.manufacturer_url = manufacturer_url
        if model_name is not None:
            self.model_name = model_name
        if model_description is not None:
            self.model_description = model_description
        if model_number is not None:
            self.model_number = model_number
        if model_url is not None:
            self.model_url = model_url
        if serial_number is not None:
            self.serial_number = serial_number
        if enable_album_art_in_didl is not None:
            self.enable_album_art_in_didl = enable_album_art_in_didl
        if enable_single_album_art_limit is not None:
            self.enable_single_album_art_limit = enable_single_album_art_limit
        if enable_single_subtitle_limit is not None:
            self.enable_single_subtitle_limit = enable_single_subtitle_limit
        if protocol_info is not None:
            self.protocol_info = protocol_info
        if timeline_offset_seconds is not None:
            self.timeline_offset_seconds = timeline_offset_seconds
        if requires_plain_video_items is not None:
            self.requires_plain_video_items = requires_plain_video_items
        if requires_plain_folders is not None:
            self.requires_plain_folders = requires_plain_folders
        if ignore_transcode_byte_range_requests is not None:
            self.ignore_transcode_byte_range_requests = ignore_transcode_byte_range_requests
        if supports_samsung_bookmark is not None:
            self.supports_samsung_bookmark = supports_samsung_bookmark
        if identification is not None:
            self.identification = identification
        if protocol_info_detection is not None:
            self.protocol_info_detection = protocol_info_detection
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if supported_media_types is not None:
            self.supported_media_types = supported_media_types
        if max_streaming_bitrate is not None:
            self.max_streaming_bitrate = max_streaming_bitrate
        if music_streaming_transcoding_bitrate is not None:
            self.music_streaming_transcoding_bitrate = music_streaming_transcoding_bitrate
        if max_static_music_bitrate is not None:
            self.max_static_music_bitrate = max_static_music_bitrate
        if direct_play_profiles is not None:
            self.direct_play_profiles = direct_play_profiles
        if transcoding_profiles is not None:
            self.transcoding_profiles = transcoding_profiles
        if container_profiles is not None:
            self.container_profiles = container_profiles
        if codec_profiles is not None:
            self.codec_profiles = codec_profiles
        if response_profiles is not None:
            self.response_profiles = response_profiles
        if subtitle_profiles is not None:
            self.subtitle_profiles = subtitle_profiles

    @property
    def type(self):
        """Gets the type of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The type of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: DlnaProfilesDeviceProfileType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DlnaProfilesDlnaProfile.


        :param type: The type of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: DlnaProfilesDeviceProfileType
        """

        self._type = type

    @property
    def path(self):
        """Gets the path of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The path of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this DlnaProfilesDlnaProfile.


        :param path: The path of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def user_id(self):
        """Gets the user_id of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The user_id of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this DlnaProfilesDlnaProfile.


        :param user_id: The user_id of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def album_art_pn(self):
        """Gets the album_art_pn of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The album_art_pn of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: str
        """
        return self._album_art_pn

    @album_art_pn.setter
    def album_art_pn(self, album_art_pn):
        """Sets the album_art_pn of this DlnaProfilesDlnaProfile.


        :param album_art_pn: The album_art_pn of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: str
        """

        self._album_art_pn = album_art_pn

    @property
    def max_album_art_width(self):
        """Gets the max_album_art_width of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The max_album_art_width of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: int
        """
        return self._max_album_art_width

    @max_album_art_width.setter
    def max_album_art_width(self, max_album_art_width):
        """Sets the max_album_art_width of this DlnaProfilesDlnaProfile.


        :param max_album_art_width: The max_album_art_width of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: int
        """

        self._max_album_art_width = max_album_art_width

    @property
    def max_album_art_height(self):
        """Gets the max_album_art_height of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The max_album_art_height of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: int
        """
        return self._max_album_art_height

    @max_album_art_height.setter
    def max_album_art_height(self, max_album_art_height):
        """Sets the max_album_art_height of this DlnaProfilesDlnaProfile.


        :param max_album_art_height: The max_album_art_height of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: int
        """

        self._max_album_art_height = max_album_art_height

    @property
    def max_icon_width(self):
        """Gets the max_icon_width of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The max_icon_width of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: int
        """
        return self._max_icon_width

    @max_icon_width.setter
    def max_icon_width(self, max_icon_width):
        """Sets the max_icon_width of this DlnaProfilesDlnaProfile.


        :param max_icon_width: The max_icon_width of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: int
        """

        self._max_icon_width = max_icon_width

    @property
    def max_icon_height(self):
        """Gets the max_icon_height of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The max_icon_height of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: int
        """
        return self._max_icon_height

    @max_icon_height.setter
    def max_icon_height(self, max_icon_height):
        """Sets the max_icon_height of this DlnaProfilesDlnaProfile.


        :param max_icon_height: The max_icon_height of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: int
        """

        self._max_icon_height = max_icon_height

    @property
    def friendly_name(self):
        """Gets the friendly_name of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The friendly_name of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: str
        """
        return self._friendly_name

    @friendly_name.setter
    def friendly_name(self, friendly_name):
        """Sets the friendly_name of this DlnaProfilesDlnaProfile.


        :param friendly_name: The friendly_name of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: str
        """

        self._friendly_name = friendly_name

    @property
    def manufacturer(self):
        """Gets the manufacturer of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The manufacturer of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: str
        """
        return self._manufacturer

    @manufacturer.setter
    def manufacturer(self, manufacturer):
        """Sets the manufacturer of this DlnaProfilesDlnaProfile.


        :param manufacturer: The manufacturer of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: str
        """

        self._manufacturer = manufacturer

    @property
    def manufacturer_url(self):
        """Gets the manufacturer_url of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The manufacturer_url of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: str
        """
        return self._manufacturer_url

    @manufacturer_url.setter
    def manufacturer_url(self, manufacturer_url):
        """Sets the manufacturer_url of this DlnaProfilesDlnaProfile.


        :param manufacturer_url: The manufacturer_url of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: str
        """

        self._manufacturer_url = manufacturer_url

    @property
    def model_name(self):
        """Gets the model_name of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The model_name of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: str
        """
        return self._model_name

    @model_name.setter
    def model_name(self, model_name):
        """Sets the model_name of this DlnaProfilesDlnaProfile.


        :param model_name: The model_name of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: str
        """

        self._model_name = model_name

    @property
    def model_description(self):
        """Gets the model_description of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The model_description of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: str
        """
        return self._model_description

    @model_description.setter
    def model_description(self, model_description):
        """Sets the model_description of this DlnaProfilesDlnaProfile.


        :param model_description: The model_description of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: str
        """

        self._model_description = model_description

    @property
    def model_number(self):
        """Gets the model_number of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The model_number of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: str
        """
        return self._model_number

    @model_number.setter
    def model_number(self, model_number):
        """Sets the model_number of this DlnaProfilesDlnaProfile.


        :param model_number: The model_number of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: str
        """

        self._model_number = model_number

    @property
    def model_url(self):
        """Gets the model_url of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The model_url of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: str
        """
        return self._model_url

    @model_url.setter
    def model_url(self, model_url):
        """Sets the model_url of this DlnaProfilesDlnaProfile.


        :param model_url: The model_url of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: str
        """

        self._model_url = model_url

    @property
    def serial_number(self):
        """Gets the serial_number of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The serial_number of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this DlnaProfilesDlnaProfile.


        :param serial_number: The serial_number of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: str
        """

        self._serial_number = serial_number

    @property
    def enable_album_art_in_didl(self):
        """Gets the enable_album_art_in_didl of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The enable_album_art_in_didl of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: bool
        """
        return self._enable_album_art_in_didl

    @enable_album_art_in_didl.setter
    def enable_album_art_in_didl(self, enable_album_art_in_didl):
        """Sets the enable_album_art_in_didl of this DlnaProfilesDlnaProfile.


        :param enable_album_art_in_didl: The enable_album_art_in_didl of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: bool
        """

        self._enable_album_art_in_didl = enable_album_art_in_didl

    @property
    def enable_single_album_art_limit(self):
        """Gets the enable_single_album_art_limit of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The enable_single_album_art_limit of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: bool
        """
        return self._enable_single_album_art_limit

    @enable_single_album_art_limit.setter
    def enable_single_album_art_limit(self, enable_single_album_art_limit):
        """Sets the enable_single_album_art_limit of this DlnaProfilesDlnaProfile.


        :param enable_single_album_art_limit: The enable_single_album_art_limit of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: bool
        """

        self._enable_single_album_art_limit = enable_single_album_art_limit

    @property
    def enable_single_subtitle_limit(self):
        """Gets the enable_single_subtitle_limit of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The enable_single_subtitle_limit of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: bool
        """
        return self._enable_single_subtitle_limit

    @enable_single_subtitle_limit.setter
    def enable_single_subtitle_limit(self, enable_single_subtitle_limit):
        """Sets the enable_single_subtitle_limit of this DlnaProfilesDlnaProfile.


        :param enable_single_subtitle_limit: The enable_single_subtitle_limit of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: bool
        """

        self._enable_single_subtitle_limit = enable_single_subtitle_limit

    @property
    def protocol_info(self):
        """Gets the protocol_info of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The protocol_info of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: str
        """
        return self._protocol_info

    @protocol_info.setter
    def protocol_info(self, protocol_info):
        """Sets the protocol_info of this DlnaProfilesDlnaProfile.


        :param protocol_info: The protocol_info of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: str
        """

        self._protocol_info = protocol_info

    @property
    def timeline_offset_seconds(self):
        """Gets the timeline_offset_seconds of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The timeline_offset_seconds of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: int
        """
        return self._timeline_offset_seconds

    @timeline_offset_seconds.setter
    def timeline_offset_seconds(self, timeline_offset_seconds):
        """Sets the timeline_offset_seconds of this DlnaProfilesDlnaProfile.


        :param timeline_offset_seconds: The timeline_offset_seconds of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: int
        """

        self._timeline_offset_seconds = timeline_offset_seconds

    @property
    def requires_plain_video_items(self):
        """Gets the requires_plain_video_items of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The requires_plain_video_items of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: bool
        """
        return self._requires_plain_video_items

    @requires_plain_video_items.setter
    def requires_plain_video_items(self, requires_plain_video_items):
        """Sets the requires_plain_video_items of this DlnaProfilesDlnaProfile.


        :param requires_plain_video_items: The requires_plain_video_items of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: bool
        """

        self._requires_plain_video_items = requires_plain_video_items

    @property
    def requires_plain_folders(self):
        """Gets the requires_plain_folders of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The requires_plain_folders of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: bool
        """
        return self._requires_plain_folders

    @requires_plain_folders.setter
    def requires_plain_folders(self, requires_plain_folders):
        """Sets the requires_plain_folders of this DlnaProfilesDlnaProfile.


        :param requires_plain_folders: The requires_plain_folders of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: bool
        """

        self._requires_plain_folders = requires_plain_folders

    @property
    def ignore_transcode_byte_range_requests(self):
        """Gets the ignore_transcode_byte_range_requests of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The ignore_transcode_byte_range_requests of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_transcode_byte_range_requests

    @ignore_transcode_byte_range_requests.setter
    def ignore_transcode_byte_range_requests(self, ignore_transcode_byte_range_requests):
        """Sets the ignore_transcode_byte_range_requests of this DlnaProfilesDlnaProfile.


        :param ignore_transcode_byte_range_requests: The ignore_transcode_byte_range_requests of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: bool
        """

        self._ignore_transcode_byte_range_requests = ignore_transcode_byte_range_requests

    @property
    def supports_samsung_bookmark(self):
        """Gets the supports_samsung_bookmark of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The supports_samsung_bookmark of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: bool
        """
        return self._supports_samsung_bookmark

    @supports_samsung_bookmark.setter
    def supports_samsung_bookmark(self, supports_samsung_bookmark):
        """Sets the supports_samsung_bookmark of this DlnaProfilesDlnaProfile.


        :param supports_samsung_bookmark: The supports_samsung_bookmark of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: bool
        """

        self._supports_samsung_bookmark = supports_samsung_bookmark

    @property
    def identification(self):
        """Gets the identification of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The identification of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: DlnaProfilesDeviceIdentification
        """
        return self._identification

    @identification.setter
    def identification(self, identification):
        """Sets the identification of this DlnaProfilesDlnaProfile.


        :param identification: The identification of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: DlnaProfilesDeviceIdentification
        """

        self._identification = identification

    @property
    def protocol_info_detection(self):
        """Gets the protocol_info_detection of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The protocol_info_detection of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: DlnaProfilesProtocolInfoDetection
        """
        return self._protocol_info_detection

    @protocol_info_detection.setter
    def protocol_info_detection(self, protocol_info_detection):
        """Sets the protocol_info_detection of this DlnaProfilesDlnaProfile.


        :param protocol_info_detection: The protocol_info_detection of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: DlnaProfilesProtocolInfoDetection
        """

        self._protocol_info_detection = protocol_info_detection

    @property
    def name(self):
        """Gets the name of this DlnaProfilesDlnaProfile.  # noqa: E501

        The name.  # noqa: E501

        :return: The name of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DlnaProfilesDlnaProfile.

        The name.  # noqa: E501

        :param name: The name of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The id of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DlnaProfilesDlnaProfile.


        :param id: The id of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def supported_media_types(self):
        """Gets the supported_media_types of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The supported_media_types of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: str
        """
        return self._supported_media_types

    @supported_media_types.setter
    def supported_media_types(self, supported_media_types):
        """Sets the supported_media_types of this DlnaProfilesDlnaProfile.


        :param supported_media_types: The supported_media_types of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: str
        """

        self._supported_media_types = supported_media_types

    @property
    def max_streaming_bitrate(self):
        """Gets the max_streaming_bitrate of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The max_streaming_bitrate of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: int
        """
        return self._max_streaming_bitrate

    @max_streaming_bitrate.setter
    def max_streaming_bitrate(self, max_streaming_bitrate):
        """Sets the max_streaming_bitrate of this DlnaProfilesDlnaProfile.


        :param max_streaming_bitrate: The max_streaming_bitrate of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: int
        """

        self._max_streaming_bitrate = max_streaming_bitrate

    @property
    def music_streaming_transcoding_bitrate(self):
        """Gets the music_streaming_transcoding_bitrate of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The music_streaming_transcoding_bitrate of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: int
        """
        return self._music_streaming_transcoding_bitrate

    @music_streaming_transcoding_bitrate.setter
    def music_streaming_transcoding_bitrate(self, music_streaming_transcoding_bitrate):
        """Sets the music_streaming_transcoding_bitrate of this DlnaProfilesDlnaProfile.


        :param music_streaming_transcoding_bitrate: The music_streaming_transcoding_bitrate of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: int
        """

        self._music_streaming_transcoding_bitrate = music_streaming_transcoding_bitrate

    @property
    def max_static_music_bitrate(self):
        """Gets the max_static_music_bitrate of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The max_static_music_bitrate of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: int
        """
        return self._max_static_music_bitrate

    @max_static_music_bitrate.setter
    def max_static_music_bitrate(self, max_static_music_bitrate):
        """Sets the max_static_music_bitrate of this DlnaProfilesDlnaProfile.


        :param max_static_music_bitrate: The max_static_music_bitrate of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: int
        """

        self._max_static_music_bitrate = max_static_music_bitrate

    @property
    def direct_play_profiles(self):
        """Gets the direct_play_profiles of this DlnaProfilesDlnaProfile.  # noqa: E501

        The direct play profiles.  # noqa: E501

        :return: The direct_play_profiles of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: list[DirectPlayProfile]
        """
        return self._direct_play_profiles

    @direct_play_profiles.setter
    def direct_play_profiles(self, direct_play_profiles):
        """Sets the direct_play_profiles of this DlnaProfilesDlnaProfile.

        The direct play profiles.  # noqa: E501

        :param direct_play_profiles: The direct_play_profiles of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: list[DirectPlayProfile]
        """

        self._direct_play_profiles = direct_play_profiles

    @property
    def transcoding_profiles(self):
        """Gets the transcoding_profiles of this DlnaProfilesDlnaProfile.  # noqa: E501

        The transcoding profiles.  # noqa: E501

        :return: The transcoding_profiles of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: list[TranscodingProfile]
        """
        return self._transcoding_profiles

    @transcoding_profiles.setter
    def transcoding_profiles(self, transcoding_profiles):
        """Sets the transcoding_profiles of this DlnaProfilesDlnaProfile.

        The transcoding profiles.  # noqa: E501

        :param transcoding_profiles: The transcoding_profiles of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: list[TranscodingProfile]
        """

        self._transcoding_profiles = transcoding_profiles

    @property
    def container_profiles(self):
        """Gets the container_profiles of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The container_profiles of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: list[ContainerProfile]
        """
        return self._container_profiles

    @container_profiles.setter
    def container_profiles(self, container_profiles):
        """Sets the container_profiles of this DlnaProfilesDlnaProfile.


        :param container_profiles: The container_profiles of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: list[ContainerProfile]
        """

        self._container_profiles = container_profiles

    @property
    def codec_profiles(self):
        """Gets the codec_profiles of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The codec_profiles of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: list[CodecProfile]
        """
        return self._codec_profiles

    @codec_profiles.setter
    def codec_profiles(self, codec_profiles):
        """Sets the codec_profiles of this DlnaProfilesDlnaProfile.


        :param codec_profiles: The codec_profiles of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: list[CodecProfile]
        """

        self._codec_profiles = codec_profiles

    @property
    def response_profiles(self):
        """Gets the response_profiles of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The response_profiles of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: list[ResponseProfile]
        """
        return self._response_profiles

    @response_profiles.setter
    def response_profiles(self, response_profiles):
        """Sets the response_profiles of this DlnaProfilesDlnaProfile.


        :param response_profiles: The response_profiles of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: list[ResponseProfile]
        """

        self._response_profiles = response_profiles

    @property
    def subtitle_profiles(self):
        """Gets the subtitle_profiles of this DlnaProfilesDlnaProfile.  # noqa: E501


        :return: The subtitle_profiles of this DlnaProfilesDlnaProfile.  # noqa: E501
        :rtype: list[SubtitleProfile]
        """
        return self._subtitle_profiles

    @subtitle_profiles.setter
    def subtitle_profiles(self, subtitle_profiles):
        """Sets the subtitle_profiles of this DlnaProfilesDlnaProfile.


        :param subtitle_profiles: The subtitle_profiles of this DlnaProfilesDlnaProfile.  # noqa: E501
        :type: list[SubtitleProfile]
        """

        self._subtitle_profiles = subtitle_profiles

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DlnaProfilesDlnaProfile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DlnaProfilesDlnaProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class TranscodingProfile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'container': 'str',
        'type': 'DlnaProfileType',
        'video_codec': 'str',
        'audio_codec': 'str',
        'protocol': 'str',
        'estimate_content_length': 'bool',
        'enable_mpegts_m2_ts_mode': 'bool',
        'transcode_seek_info': 'TranscodeSeekInfo',
        'copy_timestamps': 'bool',
        'context': 'EncodingContext',
        'max_audio_channels': 'str',
        'min_segments': 'int',
        'segment_length': 'int',
        'break_on_non_key_frames': 'bool',
        'allow_interlaced_video_stream_copy': 'bool',
        'manifest_subtitles': 'str',
        'max_manifest_subtitles': 'int',
        'max_width': 'int',
        'max_height': 'int',
        'fill_empty_subtitle_segments': 'bool'
    }

    attribute_map = {
        'container': 'Container',
        'type': 'Type',
        'video_codec': 'VideoCodec',
        'audio_codec': 'AudioCodec',
        'protocol': 'Protocol',
        'estimate_content_length': 'EstimateContentLength',
        'enable_mpegts_m2_ts_mode': 'EnableMpegtsM2TsMode',
        'transcode_seek_info': 'TranscodeSeekInfo',
        'copy_timestamps': 'CopyTimestamps',
        'context': 'Context',
        'max_audio_channels': 'MaxAudioChannels',
        'min_segments': 'MinSegments',
        'segment_length': 'SegmentLength',
        'break_on_non_key_frames': 'BreakOnNonKeyFrames',
        'allow_interlaced_video_stream_copy': 'AllowInterlacedVideoStreamCopy',
        'manifest_subtitles': 'ManifestSubtitles',
        'max_manifest_subtitles': 'MaxManifestSubtitles',
        'max_width': 'MaxWidth',
        'max_height': 'MaxHeight',
        'fill_empty_subtitle_segments': 'FillEmptySubtitleSegments'
    }

    def __init__(self, container=None, type=None, video_codec=None, audio_codec=None, protocol=None, estimate_content_length=None, enable_mpegts_m2_ts_mode=None, transcode_seek_info=None, copy_timestamps=None, context=None, max_audio_channels=None, min_segments=None, segment_length=None, break_on_non_key_frames=None, allow_interlaced_video_stream_copy=None, manifest_subtitles=None, max_manifest_subtitles=None, max_width=None, max_height=None, fill_empty_subtitle_segments=None):  # noqa: E501
        """TranscodingProfile - a model defined in Swagger"""  # noqa: E501
        self._container = None
        self._type = None
        self._video_codec = None
        self._audio_codec = None
        self._protocol = None
        self._estimate_content_length = None
        self._enable_mpegts_m2_ts_mode = None
        self._transcode_seek_info = None
        self._copy_timestamps = None
        self._context = None
        self._max_audio_channels = None
        self._min_segments = None
        self._segment_length = None
        self._break_on_non_key_frames = None
        self._allow_interlaced_video_stream_copy = None
        self._manifest_subtitles = None
        self._max_manifest_subtitles = None
        self._max_width = None
        self._max_height = None
        self._fill_empty_subtitle_segments = None
        self.discriminator = None
        if container is not None:
            self.container = container
        if type is not None:
            self.type = type
        if video_codec is not None:
            self.video_codec = video_codec
        if audio_codec is not None:
            self.audio_codec = audio_codec
        if protocol is not None:
            self.protocol = protocol
        if estimate_content_length is not None:
            self.estimate_content_length = estimate_content_length
        if enable_mpegts_m2_ts_mode is not None:
            self.enable_mpegts_m2_ts_mode = enable_mpegts_m2_ts_mode
        if transcode_seek_info is not None:
            self.transcode_seek_info = transcode_seek_info
        if copy_timestamps is not None:
            self.copy_timestamps = copy_timestamps
        if context is not None:
            self.context = context
        if max_audio_channels is not None:
            self.max_audio_channels = max_audio_channels
        if min_segments is not None:
            self.min_segments = min_segments
        if segment_length is not None:
            self.segment_length = segment_length
        if break_on_non_key_frames is not None:
            self.break_on_non_key_frames = break_on_non_key_frames
        if allow_interlaced_video_stream_copy is not None:
            self.allow_interlaced_video_stream_copy = allow_interlaced_video_stream_copy
        if manifest_subtitles is not None:
            self.manifest_subtitles = manifest_subtitles
        if max_manifest_subtitles is not None:
            self.max_manifest_subtitles = max_manifest_subtitles
        if max_width is not None:
            self.max_width = max_width
        if max_height is not None:
            self.max_height = max_height
        if fill_empty_subtitle_segments is not None:
            self.fill_empty_subtitle_segments = fill_empty_subtitle_segments

    @property
    def container(self):
        """Gets the container of this TranscodingProfile.  # noqa: E501


        :return: The container of this TranscodingProfile.  # noqa: E501
        :rtype: str
        """
        return self._container

    @container.setter
    def container(self, container):
        """Sets the container of this TranscodingProfile.


        :param container: The container of this TranscodingProfile.  # noqa: E501
        :type: str
        """

        self._container = container

    @property
    def type(self):
        """Gets the type of this TranscodingProfile.  # noqa: E501


        :return: The type of this TranscodingProfile.  # noqa: E501
        :rtype: DlnaProfileType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this TranscodingProfile.


        :param type: The type of this TranscodingProfile.  # noqa: E501
        :type: DlnaProfileType
        """

        self._type = type

    @property
    def video_codec(self):
        """Gets the video_codec of this TranscodingProfile.  # noqa: E501


        :return: The video_codec of this TranscodingProfile.  # noqa: E501
        :rtype: str
        """
        return self._video_codec

    @video_codec.setter
    def video_codec(self, video_codec):
        """Sets the video_codec of this TranscodingProfile.


        :param video_codec: The video_codec of this TranscodingProfile.  # noqa: E501
        :type: str
        """

        self._video_codec = video_codec

    @property
    def audio_codec(self):
        """Gets the audio_codec of this TranscodingProfile.  # noqa: E501


        :return: The audio_codec of this TranscodingProfile.  # noqa: E501
        :rtype: str
        """
        return self._audio_codec

    @audio_codec.setter
    def audio_codec(self, audio_codec):
        """Sets the audio_codec of this TranscodingProfile.


        :param audio_codec: The audio_codec of this TranscodingProfile.  # noqa: E501
        :type: str
        """

        self._audio_codec = audio_codec

    @property
    def protocol(self):
        """Gets the protocol of this TranscodingProfile.  # noqa: E501


        :return: The protocol of this TranscodingProfile.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this TranscodingProfile.


        :param protocol: The protocol of this TranscodingProfile.  # noqa: E501
        :type: str
        """

        self._protocol = protocol

    @property
    def estimate_content_length(self):
        """Gets the estimate_content_length of this TranscodingProfile.  # noqa: E501


        :return: The estimate_content_length of this TranscodingProfile.  # noqa: E501
        :rtype: bool
        """
        return self._estimate_content_length

    @estimate_content_length.setter
    def estimate_content_length(self, estimate_content_length):
        """Sets the estimate_content_length of this TranscodingProfile.


        :param estimate_content_length: The estimate_content_length of this TranscodingProfile.  # noqa: E501
        :type: bool
        """

        self._estimate_content_length = estimate_content_length

    @property
    def enable_mpegts_m2_ts_mode(self):
        """Gets the enable_mpegts_m2_ts_mode of this TranscodingProfile.  # noqa: E501


        :return: The enable_mpegts_m2_ts_mode of this TranscodingProfile.  # noqa: E501
        :rtype: bool
        """
        return self._enable_mpegts_m2_ts_mode

    @enable_mpegts_m2_ts_mode.setter
    def enable_mpegts_m2_ts_mode(self, enable_mpegts_m2_ts_mode):
        """Sets the enable_mpegts_m2_ts_mode of this TranscodingProfile.


        :param enable_mpegts_m2_ts_mode: The enable_mpegts_m2_ts_mode of this TranscodingProfile.  # noqa: E501
        :type: bool
        """

        self._enable_mpegts_m2_ts_mode = enable_mpegts_m2_ts_mode

    @property
    def transcode_seek_info(self):
        """Gets the transcode_seek_info of this TranscodingProfile.  # noqa: E501


        :return: The transcode_seek_info of this TranscodingProfile.  # noqa: E501
        :rtype: TranscodeSeekInfo
        """
        return self._transcode_seek_info

    @transcode_seek_info.setter
    def transcode_seek_info(self, transcode_seek_info):
        """Sets the transcode_seek_info of this TranscodingProfile.


        :param transcode_seek_info: The transcode_seek_info of this TranscodingProfile.  # noqa: E501
        :type: TranscodeSeekInfo
        """

        self._transcode_seek_info = transcode_seek_info

    @property
    def copy_timestamps(self):
        """Gets the copy_timestamps of this TranscodingProfile.  # noqa: E501


        :return: The copy_timestamps of this TranscodingProfile.  # noqa: E501
        :rtype: bool
        """
        return self._copy_timestamps

    @copy_timestamps.setter
    def copy_timestamps(self, copy_timestamps):
        """Sets the copy_timestamps of this TranscodingProfile.


        :param copy_timestamps: The copy_timestamps of this TranscodingProfile.  # noqa: E501
        :type: bool
        """

        self._copy_timestamps = copy_timestamps

    @property
    def context(self):
        """Gets the context of this TranscodingProfile.  # noqa: E501


        :return: The context of this TranscodingProfile.  # noqa: E501
        :rtype: EncodingContext
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this TranscodingProfile.


        :param context: The context of this TranscodingProfile.  # noqa: E501
        :type: EncodingContext
        """

        self._context = context

    @property
    def max_audio_channels(self):
        """Gets the max_audio_channels of this TranscodingProfile.  # noqa: E501


        :return: The max_audio_channels of this TranscodingProfile.  # noqa: E501
        :rtype: str
        """
        return self._max_audio_channels

    @max_audio_channels.setter
    def max_audio_channels(self, max_audio_channels):
        """Sets the max_audio_channels of this TranscodingProfile.


        :param max_audio_channels: The max_audio_channels of this TranscodingProfile.  # noqa: E501
        :type: str
        """

        self._max_audio_channels = max_audio_channels

    @property
    def min_segments(self):
        """Gets the min_segments of this TranscodingProfile.  # noqa: E501


        :return: The min_segments of this TranscodingProfile.  # noqa: E501
        :rtype: int
        """
        return self._min_segments

    @min_segments.setter
    def min_segments(self, min_segments):
        """Sets the min_segments of this TranscodingProfile.


        :param min_segments: The min_segments of this TranscodingProfile.  # noqa: E501
        :type: int
        """

        self._min_segments = min_segments

    @property
    def segment_length(self):
        """Gets the segment_length of this TranscodingProfile.  # noqa: E501


        :return: The segment_length of this TranscodingProfile.  # noqa: E501
        :rtype: int
        """
        return self._segment_length

    @segment_length.setter
    def segment_length(self, segment_length):
        """Sets the segment_length of this TranscodingProfile.


        :param segment_length: The segment_length of this TranscodingProfile.  # noqa: E501
        :type: int
        """

        self._segment_length = segment_length

    @property
    def break_on_non_key_frames(self):
        """Gets the break_on_non_key_frames of this TranscodingProfile.  # noqa: E501


        :return: The break_on_non_key_frames of this TranscodingProfile.  # noqa: E501
        :rtype: bool
        """
        return self._break_on_non_key_frames

    @break_on_non_key_frames.setter
    def break_on_non_key_frames(self, break_on_non_key_frames):
        """Sets the break_on_non_key_frames of this TranscodingProfile.


        :param break_on_non_key_frames: The break_on_non_key_frames of this TranscodingProfile.  # noqa: E501
        :type: bool
        """

        self._break_on_non_key_frames = break_on_non_key_frames

    @property
    def allow_interlaced_video_stream_copy(self):
        """Gets the allow_interlaced_video_stream_copy of this TranscodingProfile.  # noqa: E501


        :return: The allow_interlaced_video_stream_copy of this TranscodingProfile.  # noqa: E501
        :rtype: bool
        """
        return self._allow_interlaced_video_stream_copy

    @allow_interlaced_video_stream_copy.setter
    def allow_interlaced_video_stream_copy(self, allow_interlaced_video_stream_copy):
        """Sets the allow_interlaced_video_stream_copy of this TranscodingProfile.


        :param allow_interlaced_video_stream_copy: The allow_interlaced_video_stream_copy of this TranscodingProfile.  # noqa: E501
        :type: bool
        """

        self._allow_interlaced_video_stream_copy = allow_interlaced_video_stream_copy

    @property
    def manifest_subtitles(self):
        """Gets the manifest_subtitles of this TranscodingProfile.  # noqa: E501


        :return: The manifest_subtitles of this TranscodingProfile.  # noqa: E501
        :rtype: str
        """
        return self._manifest_subtitles

    @manifest_subtitles.setter
    def manifest_subtitles(self, manifest_subtitles):
        """Sets the manifest_subtitles of this TranscodingProfile.


        :param manifest_subtitles: The manifest_subtitles of this TranscodingProfile.  # noqa: E501
        :type: str
        """

        self._manifest_subtitles = manifest_subtitles

    @property
    def max_manifest_subtitles(self):
        """Gets the max_manifest_subtitles of this TranscodingProfile.  # noqa: E501


        :return: The max_manifest_subtitles of this TranscodingProfile.  # noqa: E501
        :rtype: int
        """
        return self._max_manifest_subtitles

    @max_manifest_subtitles.setter
    def max_manifest_subtitles(self, max_manifest_subtitles):
        """Sets the max_manifest_subtitles of this TranscodingProfile.


        :param max_manifest_subtitles: The max_manifest_subtitles of this TranscodingProfile.  # noqa: E501
        :type: int
        """

        self._max_manifest_subtitles = max_manifest_subtitles

    @property
    def max_width(self):
        """Gets the max_width of this TranscodingProfile.  # noqa: E501


        :return: The max_width of this TranscodingProfile.  # noqa: E501
        :rtype: int
        """
        return self._max_width

    @max_width.setter
    def max_width(self, max_width):
        """Sets the max_width of this TranscodingProfile.


        :param max_width: The max_width of this TranscodingProfile.  # noqa: E501
        :type: int
        """

        self._max_width = max_width

    @property
    def max_height(self):
        """Gets the max_height of this TranscodingProfile.  # noqa: E501


        :return: The max_height of this TranscodingProfile.  # noqa: E501
        :rtype: int
        """
        return self._max_height

    @max_height.setter
    def max_height(self, max_height):
        """Sets the max_height of this TranscodingProfile.


        :param max_height: The max_height of this TranscodingProfile.  # noqa: E501
        :type: int
        """

        self._max_height = max_height

    @property
    def fill_empty_subtitle_segments(self):
        """Gets the fill_empty_subtitle_segments of this TranscodingProfile.  # noqa: E501


        :return: The fill_empty_subtitle_segments of this TranscodingProfile.  # noqa: E501
        :rtype: bool
        """
        return self._fill_empty_subtitle_segments

    @fill_empty_subtitle_segments.setter
    def fill_empty_subtitle_segments(self, fill_empty_subtitle_segments):
        """Sets the fill_empty_subtitle_segments of this TranscodingProfile.


        :param fill_empty_subtitle_segments: The fill_empty_subtitle_segments of this TranscodingProfile.  # noqa: E501
        :type: bool
        """

        self._fill_empty_subtitle_segments = fill_empty_subtitle_segments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TranscodingProfile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TranscodingProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from emby_client.api_client import ApiClient


class LiveStreamServiceApi(object):
    """NOTE: This class is auto generated.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_livetv_liverecordings_by_id_hls_by_segment(self, id, segment, **kwargs):  # noqa: E501
        """Gets a live recording  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_livetv_liverecordings_by_id_hls_by_segment(id, segment, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str segment: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_livetv_liverecordings_by_id_hls_by_segment_with_http_info(id, segment, **kwargs)  # noqa: E501
        else:
            (data) = self.get_livetv_liverecordings_by_id_hls_by_segment_with_http_info(id, segment, **kwargs)  # noqa: E501
            return data

    def get_livetv_liverecordings_by_id_hls_by_segment_with_http_info(self, id, segment, **kwargs):  # noqa: E501
        """Gets a live recording  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_livetv_liverecordings_by_id_hls_by_segment_with_http_info(id, segment, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str segment: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'segment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_livetv_liverecordings_by_id_hls_by_segment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_livetv_liverecordings_by_id_hls_by_segment`")  # noqa: E501
        # verify the required parameter 'segment' is set
        if ('segment' not in params or
                params['segment'] is None):
            raise ValueError("Missing the required parameter `segment` when calling `get_livetv_liverecordings_by_id_hls_by_segment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501
        if 'segment' in params:
            path_params['Segment'] = params['segment']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/LiveTv/LiveRecordings/{Id}/hls/{Segment}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_livetv_liverecordings_by_id_hls_live_m3u8(self, id, **kwargs):  # noqa: E501
        """Gets a live recording  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_livetv_liverecordings_by_id_hls_live_m3u8(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_livetv_liverecordings_by_id_hls_live_m3u8_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_livetv_liverecordings_by_id_hls_live_m3u8_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_livetv_liverecordings_by_id_hls_live_m3u8_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets a live recording  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_livetv_liverecordings_by_id_hls_live_m3u8_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_livetv_liverecordings_by_id_hls_live_m3u8" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_livetv_liverecordings_by_id_hls_live_m3u8`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/LiveTv/LiveRecordings/{Id}/hls/live.m3u8', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_livetv_liverecordings_by_id_hls_master_m3u8(self, id, **kwargs):  # noqa: E501
        """Gets a live recording  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_livetv_liverecordings_by_id_hls_master_m3u8(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_livetv_liverecordings_by_id_hls_master_m3u8_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_livetv_liverecordings_by_id_hls_master_m3u8_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_livetv_liverecordings_by_id_hls_master_m3u8_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets a live recording  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_livetv_liverecordings_by_id_hls_master_m3u8_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_livetv_liverecordings_by_id_hls_master_m3u8" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_livetv_liverecordings_by_id_hls_master_m3u8`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/LiveTv/LiveRecordings/{Id}/hls/master.m3u8', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_livetv_liverecordings_by_id_stream(self, id, **kwargs):  # noqa: E501
        """Gets a live tv channel  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_livetv_liverecordings_by_id_stream(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_livetv_liverecordings_by_id_stream_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_livetv_liverecordings_by_id_stream_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_livetv_liverecordings_by_id_stream_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets a live tv channel  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_livetv_liverecordings_by_id_stream_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_livetv_liverecordings_by_id_stream" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_livetv_liverecordings_by_id_stream`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/LiveTv/LiveRecordings/{Id}/stream', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_livetv_livestreamfiles_by_id_hls_by_segment(self, id, segment, **kwargs):  # noqa: E501
        """Gets a live tv channel  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_livetv_livestreamfiles_by_id_hls_by_segment(id, segment, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str segment: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_livetv_livestreamfiles_by_id_hls_by_segment_with_http_info(id, segment, **kwargs)  # noqa: E501
        else:
            (data) = self.get_livetv_livestreamfiles_by_id_hls_by_segment_with_http_info(id, segment, **kwargs)  # noqa: E501
            return data

    def get_livetv_livestreamfiles_by_id_hls_by_segment_with_http_info(self, id, segment, **kwargs):  # noqa: E501
        """Gets a live tv channel  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_livetv_livestreamfiles_by_id_hls_by_segment_with_http_info(id, segment, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str segment: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'segment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_livetv_livestreamfiles_by_id_hls_by_segment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_livetv_livestreamfiles_by_id_hls_by_segment`")  # noqa: E501
        # verify the required parameter 'segment' is set
        if ('segment' not in params or
                params['segment'] is None):
            raise ValueError("Missing the required parameter `segment` when calling `get_livetv_livestreamfiles_by_id_hls_by_segment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501
        if 'segment' in params:
            path_params['Segment'] = params['segment']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/LiveTv/LiveStreamFiles/{Id}/hls/{Segment}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_livetv_livestreamfiles_by_id_hls_live_m3u8(self, id, **kwargs):  # noqa: E501
        """Gets a live tv channel  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_livetv_livestreamfiles_by_id_hls_live_m3u8(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_livetv_livestreamfiles_by_id_hls_live_m3u8_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_livetv_livestreamfiles_by_id_hls_live_m3u8_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_livetv_livestreamfiles_by_id_hls_live_m3u8_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets a live tv channel  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_livetv_livestreamfiles_by_id_hls_live_m3u8_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_livetv_livestreamfiles_by_id_hls_live_m3u8" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_livetv_livestreamfiles_by_id_hls_live_m3u8`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/LiveTv/LiveStreamFiles/{Id}/hls/live.m3u8', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_livetv_livestreamfiles_by_id_hls_master_m3u8(self, id, **kwargs):  # noqa: E501
        """Gets a live tv channel  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_livetv_livestreamfiles_by_id_hls_master_m3u8(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_livetv_livestreamfiles_by_id_hls_master_m3u8_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_livetv_livestreamfiles_by_id_hls_master_m3u8_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_livetv_livestreamfiles_by_id_hls_master_m3u8_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets a live tv channel  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_livetv_livestreamfiles_by_id_hls_master_m3u8_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_livetv_livestreamfiles_by_id_hls_master_m3u8" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_livetv_livestreamfiles_by_id_hls_master_m3u8`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/LiveTv/LiveStreamFiles/{Id}/hls/master.m3u8', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_livetv_livestreamfiles_by_id_stream_by_container(self, id, container, **kwargs):  # noqa: E501
        """Gets a live tv channel  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_livetv_livestreamfiles_by_id_stream_by_container(id, container, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str container: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_livetv_livestreamfiles_by_id_stream_by_container_with_http_info(id, container, **kwargs)  # noqa: E501
        else:
            (data) = self.get_livetv_livestreamfiles_by_id_stream_by_container_with_http_info(id, container, **kwargs)  # noqa: E501
            return data

    def get_livetv_livestreamfiles_by_id_stream_by_container_with_http_info(self, id, container, **kwargs):  # noqa: E501
        """Gets a live tv channel  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_livetv_livestreamfiles_by_id_stream_by_container_with_http_info(id, container, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str container: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'container']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_livetv_livestreamfiles_by_id_stream_by_container" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_livetv_livestreamfiles_by_id_stream_by_container`")  # noqa: E501
        # verify the required parameter 'container' is set
        if ('container' not in params or
                params['container'] is None):
            raise ValueError("Missing the required parameter `container` when calling `get_livetv_livestreamfiles_by_id_stream_by_container`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501
        if 'container' in params:
            path_params['Container'] = params['container']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/LiveTv/LiveStreamFiles/{Id}/stream.{Container}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def head_livetv_liverecordings_by_id_hls_by_segment(self, id, segment, **kwargs):  # noqa: E501
        """Gets a live recording  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_livetv_liverecordings_by_id_hls_by_segment(id, segment, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str segment: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.head_livetv_liverecordings_by_id_hls_by_segment_with_http_info(id, segment, **kwargs)  # noqa: E501
        else:
            (data) = self.head_livetv_liverecordings_by_id_hls_by_segment_with_http_info(id, segment, **kwargs)  # noqa: E501
            return data

    def head_livetv_liverecordings_by_id_hls_by_segment_with_http_info(self, id, segment, **kwargs):  # noqa: E501
        """Gets a live recording  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_livetv_liverecordings_by_id_hls_by_segment_with_http_info(id, segment, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str segment: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'segment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method head_livetv_liverecordings_by_id_hls_by_segment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `head_livetv_liverecordings_by_id_hls_by_segment`")  # noqa: E501
        # verify the required parameter 'segment' is set
        if ('segment' not in params or
                params['segment'] is None):
            raise ValueError("Missing the required parameter `segment` when calling `head_livetv_liverecordings_by_id_hls_by_segment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501
        if 'segment' in params:
            path_params['Segment'] = params['segment']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/LiveTv/LiveRecordings/{Id}/hls/{Segment}', 'HEAD',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def head_livetv_liverecordings_by_id_hls_live_m3u8(self, id, **kwargs):  # noqa: E501
        """Gets a live recording  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_livetv_liverecordings_by_id_hls_live_m3u8(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.head_livetv_liverecordings_by_id_hls_live_m3u8_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.head_livetv_liverecordings_by_id_hls_live_m3u8_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def head_livetv_liverecordings_by_id_hls_live_m3u8_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets a live recording  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_livetv_liverecordings_by_id_hls_live_m3u8_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method head_livetv_liverecordings_by_id_hls_live_m3u8" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `head_livetv_liverecordings_by_id_hls_live_m3u8`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/LiveTv/LiveRecordings/{Id}/hls/live.m3u8', 'HEAD',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def head_livetv_liverecordings_by_id_hls_master_m3u8(self, id, **kwargs):  # noqa: E501
        """Gets a live recording  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_livetv_liverecordings_by_id_hls_master_m3u8(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.head_livetv_liverecordings_by_id_hls_master_m3u8_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.head_livetv_liverecordings_by_id_hls_master_m3u8_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def head_livetv_liverecordings_by_id_hls_master_m3u8_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets a live recording  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_livetv_liverecordings_by_id_hls_master_m3u8_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method head_livetv_liverecordings_by_id_hls_master_m3u8" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `head_livetv_liverecordings_by_id_hls_master_m3u8`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/LiveTv/LiveRecordings/{Id}/hls/master.m3u8', 'HEAD',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def head_livetv_livestreamfiles_by_id_hls_by_segment(self, id, segment, **kwargs):  # noqa: E501
        """Gets a live tv channel  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_livetv_livestreamfiles_by_id_hls_by_segment(id, segment, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str segment: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.head_livetv_livestreamfiles_by_id_hls_by_segment_with_http_info(id, segment, **kwargs)  # noqa: E501
        else:
            (data) = self.head_livetv_livestreamfiles_by_id_hls_by_segment_with_http_info(id, segment, **kwargs)  # noqa: E501
            return data

    def head_livetv_livestreamfiles_by_id_hls_by_segment_with_http_info(self, id, segment, **kwargs):  # noqa: E501
        """Gets a live tv channel  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_livetv_livestreamfiles_by_id_hls_by_segment_with_http_info(id, segment, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str segment: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'segment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method head_livetv_livestreamfiles_by_id_hls_by_segment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `head_livetv_livestreamfiles_by_id_hls_by_segment`")  # noqa: E501
        # verify the required parameter 'segment' is set
        if ('segment' not in params or
                params['segment'] is None):
            raise ValueError("Missing the required parameter `segment` when calling `head_livetv_livestreamfiles_by_id_hls_by_segment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501
        if 'segment' in params:
            path_params['Segment'] = params['segment']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/LiveTv/LiveStreamFiles/{Id}/hls/{Segment}', 'HEAD',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def head_livetv_livestreamfiles_by_id_hls_live_m3u8(self, id, **kwargs):  # noqa: E501
        """Gets a live tv channel  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_livetv_livestreamfiles_by_id_hls_live_m3u8(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.head_livetv_livestreamfiles_by_id_hls_live_m3u8_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.head_livetv_livestreamfiles_by_id_hls_live_m3u8_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def head_livetv_livestreamfiles_by_id_hls_live_m3u8_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets a live tv channel  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_livetv_livestreamfiles_by_id_hls_live_m3u8_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method head_livetv_livestreamfiles_by_id_hls_live_m3u8" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `head_livetv_livestreamfiles_by_id_hls_live_m3u8`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/LiveTv/LiveStreamFiles/{Id}/hls/live.m3u8', 'HEAD',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def head_livetv_livestreamfiles_by_id_hls_master_m3u8(self, id, **kwargs):  # noqa: E501
        """Gets a live tv channel  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_livetv_livestreamfiles_by_id_hls_master_m3u8(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.head_livetv_livestreamfiles_by_id_hls_master_m3u8_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.head_livetv_livestreamfiles_by_id_hls_master_m3u8_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def head_livetv_livestreamfiles_by_id_hls_master_m3u8_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets a live tv channel  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_livetv_livestreamfiles_by_id_hls_master_m3u8_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method head_livetv_livestreamfiles_by_id_hls_master_m3u8" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `head_livetv_livestreamfiles_by_id_hls_master_m3u8`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/LiveTv/LiveStreamFiles/{Id}/hls/master.m3u8', 'HEAD',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class UserAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'server_id': 'str',
        'user_id': 'str',
        'item_id': 'str',
        'type': 'UserActionType',
        '_date': 'datetime',
        'position_ticks': 'int',
        'played': 'bool',
        'is_favorite': 'bool'
    }

    attribute_map = {
        'id': 'Id',
        'server_id': 'ServerId',
        'user_id': 'UserId',
        'item_id': 'ItemId',
        'type': 'Type',
        '_date': 'Date',
        'position_ticks': 'PositionTicks',
        'played': 'Played',
        'is_favorite': 'IsFavorite'
    }

    def __init__(self, id=None, server_id=None, user_id=None, item_id=None, type=None, _date=None, position_ticks=None, played=None, is_favorite=None):  # noqa: E501
        """UserAction - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._server_id = None
        self._user_id = None
        self._item_id = None
        self._type = None
        self.__date = None
        self._position_ticks = None
        self._played = None
        self._is_favorite = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if server_id is not None:
            self.server_id = server_id
        if user_id is not None:
            self.user_id = user_id
        if item_id is not None:
            self.item_id = item_id
        if type is not None:
            self.type = type
        if _date is not None:
            self._date = _date
        if position_ticks is not None:
            self.position_ticks = position_ticks
        if played is not None:
            self.played = played
        if is_favorite is not None:
            self.is_favorite = is_favorite

    @property
    def id(self):
        """Gets the id of this UserAction.  # noqa: E501


        :return: The id of this UserAction.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserAction.


        :param id: The id of this UserAction.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def server_id(self):
        """Gets the server_id of this UserAction.  # noqa: E501


        :return: The server_id of this UserAction.  # noqa: E501
        :rtype: str
        """
        return self._server_id

    @server_id.setter
    def server_id(self, server_id):
        """Sets the server_id of this UserAction.


        :param server_id: The server_id of this UserAction.  # noqa: E501
        :type: str
        """

        self._server_id = server_id

    @property
    def user_id(self):
        """Gets the user_id of this UserAction.  # noqa: E501


        :return: The user_id of this UserAction.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this UserAction.


        :param user_id: The user_id of this UserAction.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def item_id(self):
        """Gets the item_id of this UserAction.  # noqa: E501


        :return: The item_id of this UserAction.  # noqa: E501
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this UserAction.


        :param item_id: The item_id of this UserAction.  # noqa: E501
        :type: str
        """

        self._item_id = item_id

    @property
    def type(self):
        """Gets the type of this UserAction.  # noqa: E501


        :return: The type of this UserAction.  # noqa: E501
        :rtype: UserActionType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this UserAction.


        :param type: The type of this UserAction.  # noqa: E501
        :type: UserActionType
        """

        self._type = type

    @property
    def _date(self):
        """Gets the _date of this UserAction.  # noqa: E501


        :return: The _date of this UserAction.  # noqa: E501
        :rtype: datetime
        """
        return self.__date

    @_date.setter
    def _date(self, _date):
        """Sets the _date of this UserAction.


        :param _date: The _date of this UserAction.  # noqa: E501
        :type: datetime
        """

        self.__date = _date

    @property
    def position_ticks(self):
        """Gets the position_ticks of this UserAction.  # noqa: E501


        :return: The position_ticks of this UserAction.  # noqa: E501
        :rtype: int
        """
        return self._position_ticks

    @position_ticks.setter
    def position_ticks(self, position_ticks):
        """Sets the position_ticks of this UserAction.


        :param position_ticks: The position_ticks of this UserAction.  # noqa: E501
        :type: int
        """

        self._position_ticks = position_ticks

    @property
    def played(self):
        """Gets the played of this UserAction.  # noqa: E501


        :return: The played of this UserAction.  # noqa: E501
        :rtype: bool
        """
        return self._played

    @played.setter
    def played(self, played):
        """Sets the played of this UserAction.


        :param played: The played of this UserAction.  # noqa: E501
        :type: bool
        """

        self._played = played

    @property
    def is_favorite(self):
        """Gets the is_favorite of this UserAction.  # noqa: E501


        :return: The is_favorite of this UserAction.  # noqa: E501
        :rtype: bool
        """
        return self._is_favorite

    @is_favorite.setter
    def is_favorite(self, is_favorite):
        """Sets the is_favorite of this UserAction.


        :param is_favorite: The is_favorite of this UserAction.  # noqa: E501
        :type: bool
        """

        self._is_favorite = is_favorite

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
